@@ -22,8 +22,10 @@ sub capacity_for {
   debug "checking local capacity for action $action";
 
   my $action_map = {
-    Poller => [qw/discoverall discover arpwalk arpnip macwalk macsuck/],
-    Interactive => [qw/location contact portcontrol portname vlan power/],
+      Poller => [
+          qw/discoverall discover arpwalk arpnip macwalk macsuck nbtstat nbtwalk expiry/
+      ],
+      Interactive => [qw/location contact portcontrol portname vlan power/],
   };
 
   my $role_map = {
